SystemOrganization addCategory: #DefragFAT!

TestCase subclass: #DFDefragAppOneFileTest
	instanceVariableNames: 'defrag app file'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFDefragAppOneFileTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:48'!
setUp

	|pc|
	pc := DFIBMPC new.
	pc doInstallMemorySize: 3.
	pc doInstallHardDiskSize: 40.
	pc hardDisk doFormatFAT.
	file := pc hardDisk doAddFile.
	file doAddContinuousByesFromIndex: 3 withBytes: 'lo W'.
	file doAddContinuousByesFromIndex: 10 withBytes: 'orld!!!!'.
	file doAddContinuousByesFromIndex: 20 withBytes: 'Hel'.
	app := DFDefragApp new.
	app pc: pc.
! !

!DFDefragAppOneFileTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:36'!
testDefrag

	self assert: 3 equals: file fragCount.
	app doDefrag.
	self assert: 1 equals: file fragCount.! !

!DFDefragAppOneFileTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:20'!
testSetUp

	! !

TestCase subclass: #DFDiskContinuousBytesTest
	instanceVariableNames: 'diskContinuousBytes hardDisk fat'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFDiskContinuousBytesTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:16'!
setUp

	super setUp.
	hardDisk := DFHardDisk new.
	hardDisk doAllocateSize: 30.
	fat := DFFAT new.
	fat hardDisk: hardDisk.
	diskContinuousBytes := DFDiskContinuousBytes new.
	diskContinuousBytes fileSystem: fat.! !

!DFDiskContinuousBytesTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:57'!
testFATAccessBytes

	diskContinuousBytes startingIndex: 10.
	diskContinuousBytes doWriteBytes: (ByteArray withAll: 'hello world, baby').
	! !

!DFDiskContinuousBytesTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:58'!
testFATAccessBytesErrorIfTooLong

	diskContinuousBytes startingIndex: 25.
	self should: [diskContinuousBytes doWriteBytes: (ByteArray withAll: 'hello world, baby')] raise: Error  
	.
	! !

!DFDiskContinuousBytesTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 16:08'!
testFATAccessErrorIfStartingIndexTooBig

	self should: [ diskContinuousBytes startingIndex: 40] raise: Error.
	  
	! !

!DFDiskContinuousBytesTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:57'!
testFATAccessErrorIfStartingIndexTooSmall

	self should: [ diskContinuousBytes startingIndex: -3] raise: Error.
	  
	! !

!DFDiskContinuousBytesTest methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:58'!
testFATAccessGoodStartingIndex

	self shouldnt: [ diskContinuousBytes startingIndex: 1 ] raise: Error.
	  
	! !

Object subclass: #DFDefragApp
	instanceVariableNames: 'pc'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFDefragApp methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:49'!
doDefrag

	pc hardDisk fileSystem files do: [:each| each doCheatBeDefragged]! !

!DFDefragApp methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:32'!
pc: aDFIBMPC 

	pc := aDFIBMPC! !

Object subclass: #DFDiskContinuousBytes
	instanceVariableNames: 'startingIndex length fileSystem'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFDiskContinuousBytes methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 19:26'!
doWriteBytes: aByteArray 

	self flag: 'remove inst var bytes. use delegate to fileSystem'.
	fileSystem doWriteBytes: aByteArray withStartingIndex: startingIndex.	
	length := aByteArray size.! !

!DFDiskContinuousBytes methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:34'!
fileSystem: aFileSystem 

	fileSystem := aFileSystem! !

!DFDiskContinuousBytes methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:35'!
startingIndex: anInteger 

	anInteger > fileSystem hardDiskSize ifTrue: [self error: 'starting index greater than harddisk limit'].  	
	anInteger < 1 ifTrue: [self error: 'starting index less than 1'].  	
	startingIndex := anInteger ! !

Object subclass: #DFFAT
	instanceVariableNames: 'files hardDisk'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFFAT methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:36'!
canPut: aByteArray startingAt: anInteger 

	^anInteger >= 1 and: [anInteger + aByteArray size <= hardDisk diskSize]! !

!DFFAT methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 18:19'!
doWriteBytes: aByteString withStartingIndex: aSmallInteger 

	hardDisk doWriteBytes: aByteString withStartingIndex: aSmallInteger! !

!DFFAT methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:02'!
files

	^ files! !

!DFFAT methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:59'!
hardDisk: aDFHardDisk 

	hardDisk := aDFHardDisk ! !

!DFFAT methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 16:19'!
hardDiskSize

	^hardDisk diskSize! !

!DFFAT methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:07'!
initialize 

	super initialize.
	files := OrderedCollection new.! !

Object subclass: #DFFile
	instanceVariableNames: 'continuousBytes fragCount fileSystem'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFFile methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:58'!
doAddContinuousByesFromIndex: aSmallInteger withBytes: aByteArray 

	| bytes |
	bytes := DFDiskContinuousBytes new.
	bytes fileSystem: fileSystem.
	bytes startingIndex: aSmallInteger.
	bytes doWriteBytes: aByteArray.
	
	continuousBytes add: bytes.! !

!DFFile methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:56'!
doCheatBeDefragged

	fragCount := 1.
	self flag: 'improve this cheat by making properly concatenated conBytes'
! !

!DFFile methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:19'!
fileSystem: aDFFAT 

	fileSystem := aDFFAT! !

!DFFile methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:37'!
fragCount

	^fragCount! !

!DFFile methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:39'!
initialize 

	super initialize.
	continuousBytes := OrderedCollection new.
	fragCount := 3.! !

Object subclass: #DFHardDisk
	instanceVariableNames: 'diskBytes fileSystem'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFHardDisk methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 16:20'!
diskSize

	^diskBytes size! !

!DFHardDisk methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:45'!
doAddFile

	| newFile |
	newFile := DFFile new.
	newFile fileSystem: fileSystem.
	fileSystem files add: newFile.
	^newFile! !

!DFHardDisk methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:07'!
doAllocateSize: aSmallInteger 

	self assert: diskBytes isNil.
	diskBytes := ByteArray new: aSmallInteger.! !

!DFHardDisk methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:14'!
doFormatFAT

	fileSystem := DFFAT new.
	fileSystem hardDisk: self.
! !

!DFHardDisk methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 19:24'!
doWriteBytes: aByteString withStartingIndex: aSmallInteger 

	self flag: 'rename aSmallInteger to anInteger'.
	diskBytes replaceFrom: aSmallInteger to: aSmallInteger + aByteString size - 1 with: aByteString! !

!DFHardDisk methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:12'!
fileSystem

	^ fileSystem! !

!DFHardDisk methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:07'!
initialize 

	super initialize.! !

Object subclass: #DFIBMPC
	instanceVariableNames: 'memory disk'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFIBMPC methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:42'!
doInstallHardDiskSize: anInteger

	self assert: disk isNil.
	disk := DFHardDisk new.
	disk doAllocateSize: anInteger.  ! !

!DFIBMPC methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:43'!
doInstallMemorySize: anInteger 

	self assert: memory isNil.
	memory := DFMemory new.
	memory doInstallSize: anInteger! !

!DFIBMPC methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 15:22'!
hardDisk

	^disk! !

Object subclass: #DFMemory
	instanceVariableNames: 'byteArray'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DefragFAT'!

!DFMemory methodsFor: 'as yet unclassified' stamp: 'hjo 4/17/2011 17:40'!
doInstallSize: anInteger
	 
	byteArray := ByteArray new: anInteger! !
